@@ -1,6 +1,6 @@
 # last modified 14 April 2001 by J. Fox
 
-print.sem <- function(x) {
+print.sem <- function(x, ...) {
     n <- x$n
     t <- x$t
     cat("\n Model Chisquare = ", x$criterion * (x$N - 1), 
