@@ -1,17 +1,17 @@
-# last modified 14 April 2001 by J. Fox
+# last modified 23 Dec 2001 by J. Fox
 
-ram<-function(object, digits=5, start.values=F){
+ram<-function(object, digits=5, startvalues=F){
     old.digits <- options(digits=digits)
     on.exit(options(old.digits))
     var.names <- rownames(object$A)
     ram <- object$ram
-    if (!start.values) colnames(ram) <- c(colnames(ram)[1:4], "estimate")
+    if (!startvalues) colnames(ram) <- c(colnames(ram)[1:4], "estimate")
     par <- object$coeff
     par.names <- rep(" ", nrow(ram))
     t <- object$t
     for (i in 1:t) {
         which.par <- ram[,4] == i
-        if (!start.values)  ram[which.par, 5] <- par[i]
+        if (!startvalues)  ram[which.par, 5] <- par[i]
         par.names[which.par] <- names(par)[i]
         }
     par.code <- paste(var.names[ram[,2]], c('<---', '<-->')[ram[,1]],
